@@ -18,54 +18,33 @@
 
 #include "kstartupinfo.h"
 #include "kwindowsystem_debug.h"
-#include "netwm_def.h"
 
-#if KWINDOWSYSTEM_BUILD_DEPRECATED_SINCE(5, 62)
-#include <QWidget>
-#endif
 #include <QDateTime>
 
-#include <config-kwindowsystem.h> // KWINDOWSYSTEM_HAVE_X11
-
 // need to resolve INT32(qglobal.h)<>INT32(Xlibint.h) conflict
 #ifndef QT_CLEAN_NAMESPACE
 #define QT_CLEAN_NAMESPACE
 #endif
 
-#ifndef Q_OS_WIN
+#include <QTimer>
+#include <netwm.h>
+#include <stdlib.h>
 #include <sys/time.h>
 #include <unistd.h>
-#else
-#include <process.h>
-#include <winsock2.h>
-#endif
-#include <QTimer>
-#include <stdlib.h>
-#if KWINDOWSYSTEM_HAVE_X11
-#include <netwm.h>
 
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
-#include <private/qtx11extras_p.h>
-#else
-#include <QX11Info>
-#endif
-
-#endif
 #include <QCoreApplication>
 #include <QDebug>
 #include <QStandardPaths>
-#include <signal.h>
-#if KWINDOWSYSTEM_HAVE_X11
 #include <X11/Xlib.h>
 #include <fixx11h.h>
 #include <kwindowsystem.h>
 #include <kx11extras.h>
 #include <kxmessages.h>
-#endif
+#include <private/qtx11extras_p.h>
+#include <signal.h>
 
-#if KWINDOWSYSTEM_HAVE_X11
 static const char NET_STARTUP_MSG[] = "_NET_STARTUP_INFO";
-#endif
+
 // DESKTOP_STARTUP_ID is used also in kinit/wrapper.c ,
 // kdesu in both kdelibs and kdebase and who knows where else
 static const char NET_STARTUP_ENV[] = "DESKTOP_STARTUP_ID";
@@ -129,9 +108,6 @@ struct Q_DECL_HIDDEN KStartupInfoData::Private {
     KStartupInfoData::TriState silent;
     int screen;
     int xinerama;
-#if KWINDOWSYSTEM_BUILD_DEPRECATED_SINCE(5, 69)
-    WId launched_by = 0;
-#endif
     QString application_id;
 };
 
@@ -150,9 +126,9 @@ public:
     void got_remove_startup_info(const QString &msg_P);
     void new_startup_info_internal(const KStartupInfoId &id_P, Data &data_P, bool update_only_P);
     void removeAllStartupInfoInternal(const KStartupInfoId &id_P);
-    /**
-     * Emits the gotRemoveStartup signal and erases the @p it from the startups map.
-     * @returns Iterator to next item in the startups map.
+    /*
+     * Emits the gotRemoveStartup signal and erases the it from the startups map.
+     * Returns Iterator to next item in the startups map.
      **/
     QMap<KStartupInfoId, Data>::iterator removeStartupInfoInternal(QMap<KStartupInfoId, Data>::iterator it);
     void remove_startup_pids(const KStartupInfoId &id, const KStartupInfoData &data);
@@ -164,6 +140,7 @@ public:
     void startups_cleanup_internal(bool age_P);
     void clean_all_noncompliant();
     static QString check_required_startup_fields(const QString &msg, const KStartupInfoData &data, int screen);
+    static void setWindowStartupId(WId w_P, const QByteArray &id_P);
 
     KStartupInfo *q;
     unsigned int timeout;
@@ -172,18 +149,14 @@ public:
     QMap<KStartupInfoId, KStartupInfo::Data> silent_startups;
     // contains ASN's that had change: but no new: yet
     QMap<KStartupInfoId, KStartupInfo::Data> uninited_startups;
-#if KWINDOWSYSTEM_HAVE_X11
     KXMessages msgs;
-#endif
     QTimer *cleanup;
     int flags;
 
     Private(int flags_P, KStartupInfo *qq)
         : q(qq)
         , timeout(60)
-#if KWINDOWSYSTEM_HAVE_X11
         , msgs(NET_STARTUP_MSG)
-#endif
         , cleanup(nullptr)
         , flags(flags_P)
     {
@@ -191,23 +164,17 @@ public:
 
     void createConnections()
     {
-#if KWINDOWSYSTEM_HAVE_X11
         // d == nullptr means "disabled"
         if (!QX11Info::isPlatformX11() || !QX11Info::display()) {
             return;
         }
 
         if (!(flags & DisableKWinModule)) {
-            QObject::connect(KWindowSystem::self(), SIGNAL(windowAdded(WId)), q, SLOT(slot_window_added(WId)));
-#ifdef __GNUC__
-#warning "systemTrayWindowAdded signal was remove from KWindowSystem class"
-#endif
-            // QObject::connect( KWindowSystem::self(), SIGNAL(systemTrayWindowAdded(WId)), q, SLOT(slot_window_added(WId)));
+            QObject::connect(KX11Extras::self(), SIGNAL(windowAdded(WId)), q, SLOT(slot_window_added(WId)));
         }
         QObject::connect(&msgs, SIGNAL(gotMessage(QString)), q, SLOT(got_message(QString)));
         cleanup = new QTimer(q);
         QObject::connect(cleanup, SIGNAL(timeout()), q, SLOT(startups_cleanup()));
-#endif
     }
 };
 
@@ -218,15 +185,6 @@ KStartupInfo::KStartupInfo(int flags_P, QObject *parent_P)
     d->createConnections();
 }
 
-#if KWINDOWSYSTEM_BUILD_DEPRECATED_SINCE(5, 0)
-KStartupInfo::KStartupInfo(bool clean_on_cantdetect_P, QObject *parent_P)
-    : QObject(parent_P)
-    , d(new Private(clean_on_cantdetect_P ? CleanOnCantDetect : 0, this))
-{
-    d->createConnections();
-}
-#endif
-
 KStartupInfo::~KStartupInfo()
 {
     delete d;
@@ -234,7 +192,6 @@ KStartupInfo::~KStartupInfo()
 
 void KStartupInfo::Private::got_message(const QString &msg_P)
 {
-#if KWINDOWSYSTEM_HAVE_X11
     // TODO do something with SCREEN= ?
     // qCDebug(LOG_KWINDOWSYSTEM) << "got:" << msg_P;
     QString msg = msg_P.trimmed();
@@ -245,9 +202,6 @@ void KStartupInfo::Private::got_message(const QString &msg_P)
     } else if (msg.startsWith(QLatin1String("remove:"))) { // must match length below
         got_remove_startup_info(msg.mid(7));
     }
-#else
-    Q_UNUSED(msg_P)
-#endif
 }
 
 // if the application stops responding for a while, KWindowSystem may get
@@ -266,11 +220,7 @@ public:
         , w(w_P)
     {
     }
-#if KWINDOWSYSTEM_HAVE_X11
     Window w;
-#else
-    WId w;
-#endif
     static Type uniqueType()
     {
         return Type(QEvent::User + 15);
@@ -285,11 +235,9 @@ void KStartupInfo::Private::slot_window_added(WId w_P)
 
 void KStartupInfo::customEvent(QEvent *e_P)
 {
-#if KWINDOWSYSTEM_HAVE_X11
     if (e_P->type() == DelayedWindowEvent::uniqueType()) {
         d->window_added(static_cast<DelayedWindowEvent *>(e_P)->w);
     } else
-#endif
         QObject::customEvent(e_P);
 }
 
@@ -466,53 +414,20 @@ bool KStartupInfo::sendStartup(const KStartupInfoId &id_P, const KStartupInfoDat
     if (id_P.isNull()) {
         return false;
     }
-#if KWINDOWSYSTEM_HAVE_X11
     return sendStartupXcb(QX11Info::connection(), QX11Info::appScreen(), id_P, data_P);
-#else
-    Q_UNUSED(data_P)
-#endif
-    return true;
 }
 
-#if KWINDOWSYSTEM_BUILD_DEPRECATED_SINCE(5, 18)
-bool KStartupInfo::sendStartupX(Display *disp_P, const KStartupInfoId &id_P, const KStartupInfoData &data_P)
-{
-    if (id_P.isNull()) {
-        return false;
-    }
-#if KWINDOWSYSTEM_HAVE_X11
-    QString msg = QStringLiteral("new: %1 %2").arg(id_P.d->to_text(), data_P.d->to_text());
-    msg = Private::check_required_startup_fields(msg, data_P, DefaultScreen(disp_P));
-#ifdef KSTARTUPINFO_ALL_DEBUG
-    qCDebug(LOG_KWINDOWSYSTEM) << "sending " << msg;
-#endif
-    return KXMessages::broadcastMessageX(disp_P, NET_STARTUP_MSG, msg);
-#else
-    Q_UNUSED(disp_P)
-    Q_UNUSED(data_P)
-    return true;
-#endif
-}
-#endif
-
 bool KStartupInfo::sendStartupXcb(xcb_connection_t *conn, int screen, const KStartupInfoId &id_P, const KStartupInfoData &data_P)
 {
     if (id_P.isNull()) {
         return false;
     }
-#if KWINDOWSYSTEM_HAVE_X11
     QString msg = QStringLiteral("new: %1 %2").arg(id_P.d->to_text(), data_P.d->to_text());
     msg = Private::check_required_startup_fields(msg, data_P, screen);
 #ifdef KSTARTUPINFO_ALL_DEBUG
     qCDebug(LOG_KWINDOWSYSTEM) << "sending " << msg;
 #endif
     return KXMessages::broadcastMessageX(conn, NET_STARTUP_MSG, msg, screen);
-#else
-    Q_UNUSED(conn)
-    Q_UNUSED(screen)
-    Q_UNUSED(data_P)
-    return true;
-#endif
 }
 
 QString KStartupInfo::Private::check_required_startup_fields(const QString &msg, const KStartupInfoData &data_P, int screen)
@@ -537,51 +452,19 @@ bool KStartupInfo::sendChange(const KStartupInfoId &id_P, const KStartupInfoData
     if (id_P.isNull()) {
         return false;
     }
-#if KWINDOWSYSTEM_HAVE_X11
     return sendChangeXcb(QX11Info::connection(), QX11Info::appScreen(), id_P, data_P);
-#else
-    Q_UNUSED(data_P)
-#endif
-    return true;
 }
 
-#if KWINDOWSYSTEM_BUILD_DEPRECATED_SINCE(5, 18)
-bool KStartupInfo::sendChangeX(Display *disp_P, const KStartupInfoId &id_P, const KStartupInfoData &data_P)
-{
-    if (id_P.isNull()) {
-        return false;
-    }
-#if KWINDOWSYSTEM_HAVE_X11
-    QString msg = QStringLiteral("change: %1 %2").arg(id_P.d->to_text(), data_P.d->to_text());
-#ifdef KSTARTUPINFO_ALL_DEBUG
-    qCDebug(LOG_KWINDOWSYSTEM) << "sending " << msg;
-#endif
-    return KXMessages::broadcastMessageX(disp_P, NET_STARTUP_MSG, msg);
-#else
-    Q_UNUSED(disp_P)
-    Q_UNUSED(data_P)
-    return true;
-#endif
-}
-#endif
-
 bool KStartupInfo::sendChangeXcb(xcb_connection_t *conn, int screen, const KStartupInfoId &id_P, const KStartupInfoData &data_P)
 {
     if (id_P.isNull()) {
         return false;
     }
-#if KWINDOWSYSTEM_HAVE_X11
     QString msg = QStringLiteral("change: %1 %2").arg(id_P.d->to_text(), data_P.d->to_text());
 #ifdef KSTARTUPINFO_ALL_DEBUG
     qCDebug(LOG_KWINDOWSYSTEM) << "sending " << msg;
 #endif
     return KXMessages::broadcastMessageX(conn, NET_STARTUP_MSG, msg, screen);
-#else
-    Q_UNUSED(conn)
-    Q_UNUSED(screen)
-    Q_UNUSED(data_P)
-    return true;
-#endif
 }
 
 bool KStartupInfo::sendFinish(const KStartupInfoId &id_P)
@@ -589,110 +472,46 @@ bool KStartupInfo::sendFinish(const KStartupInfoId &id_P)
     if (id_P.isNull()) {
         return false;
     }
-#if KWINDOWSYSTEM_HAVE_X11
     return sendFinishXcb(QX11Info::connection(), QX11Info::appScreen(), id_P);
-#endif
-    return true;
 }
 
-#if KWINDOWSYSTEM_BUILD_DEPRECATED_SINCE(5, 18)
-bool KStartupInfo::sendFinishX(Display *disp_P, const KStartupInfoId &id_P)
-{
-    if (id_P.isNull()) {
-        return false;
-    }
-#if KWINDOWSYSTEM_HAVE_X11
-    QString msg = QStringLiteral("remove: %1").arg(id_P.d->to_text());
-#ifdef KSTARTUPINFO_ALL_DEBUG
-    qCDebug(LOG_KWINDOWSYSTEM) << "sending " << msg;
-#endif
-    return KXMessages::broadcastMessageX(disp_P, NET_STARTUP_MSG, msg);
-#else
-    Q_UNUSED(disp_P)
-    return true;
-#endif
-}
-#endif
-
 bool KStartupInfo::sendFinishXcb(xcb_connection_t *conn, int screen, const KStartupInfoId &id_P)
 {
     if (id_P.isNull()) {
         return false;
     }
-#if KWINDOWSYSTEM_HAVE_X11
     QString msg = QStringLiteral("remove: %1").arg(id_P.d->to_text());
 #ifdef KSTARTUPINFO_ALL_DEBUG
     qCDebug(LOG_KWINDOWSYSTEM) << "sending " << msg;
 #endif
     return KXMessages::broadcastMessageX(conn, NET_STARTUP_MSG, msg, screen);
-#else
-    Q_UNUSED(conn)
-    Q_UNUSED(screen)
-    return true;
-#endif
 }
 
 bool KStartupInfo::sendFinish(const KStartupInfoId &id_P, const KStartupInfoData &data_P)
 {
-//    if( id_P.isNull()) // id may be null, the pids and hostname matter then
-//        return false;
-#if KWINDOWSYSTEM_HAVE_X11
+    //    if( id_P.isNull()) // id may be null, the pids and hostname matter then
+    //        return false;
     return sendFinishXcb(QX11Info::connection(), QX11Info::appScreen(), id_P, data_P);
-#else
-    Q_UNUSED(id_P)
-    Q_UNUSED(data_P)
-#endif
-    return true;
 }
 
-#if KWINDOWSYSTEM_BUILD_DEPRECATED_SINCE(5, 18)
-bool KStartupInfo::sendFinishX(Display *disp_P, const KStartupInfoId &id_P, const KStartupInfoData &data_P)
-{
-//    if( id_P.isNull()) // id may be null, the pids and hostname matter then
-//        return false;
-#if KWINDOWSYSTEM_HAVE_X11
-    QString msg = QStringLiteral("remove: %1 %2").arg(id_P.d->to_text(), data_P.d->to_text());
-#ifdef KSTARTUPINFO_ALL_DEBUG
-    qCDebug(LOG_KWINDOWSYSTEM) << "sending " << msg;
-#endif
-    return KXMessages::broadcastMessageX(disp_P, NET_STARTUP_MSG, msg);
-#else
-    Q_UNUSED(disp_P)
-    Q_UNUSED(id_P)
-    Q_UNUSED(data_P)
-    return true;
-#endif
-}
-#endif
-
 bool KStartupInfo::sendFinishXcb(xcb_connection_t *conn, int screen, const KStartupInfoId &id_P, const KStartupInfoData &data_P)
 {
-//    if( id_P.isNull()) // id may be null, the pids and hostname matter then
-//        return false;
-#if KWINDOWSYSTEM_HAVE_X11
+    //    if( id_P.isNull()) // id may be null, the pids and hostname matter then
+    //        return false;
     QString msg = QStringLiteral("remove: %1 %2").arg(id_P.d->to_text(), data_P.d->to_text());
 #ifdef KSTARTUPINFO_ALL_DEBUG
     qCDebug(LOG_KWINDOWSYSTEM) << "sending " << msg;
 #endif
     return KXMessages::broadcastMessageX(conn, NET_STARTUP_MSG, msg, screen);
-#else
-    Q_UNUSED(conn)
-    Q_UNUSED(screen)
-    Q_UNUSED(id_P)
-    Q_UNUSED(data_P)
-    return true;
-#endif
 }
 
 void KStartupInfo::appStarted()
 {
     QByteArray startupId = s_startup_id;
 
-#if KWINDOWSYSTEM_HAVE_X11
     if (startupId.isEmpty()) {
         startupId = QX11Info::nextStartupId();
     }
-#endif
 
     appStarted(startupId);
     setStartupId("0"); // reset the id, no longer valid (must use clearStartupId() to avoid infinite loop)
@@ -705,40 +524,11 @@ void KStartupInfo::appStarted(const QByteArray &startup_id)
     if (id.isNull()) {
         return;
     }
-#if KWINDOWSYSTEM_HAVE_X11
     if (QX11Info::isPlatformX11() && !qEnvironmentVariableIsEmpty("DISPLAY")) { // don't rely on QX11Info::display()
         KStartupInfo::sendFinish(id);
     }
-#endif
 }
 
-#if KWINDOWSYSTEM_BUILD_DEPRECATED_SINCE(5, 102)
-void KStartupInfo::silenceStartup(bool silence)
-{
-    KStartupInfoId id;
-    id.initId(startupId());
-    if (id.isNull()) {
-        return;
-    }
-    KStartupInfoData data;
-    data.setSilent(silence ? KStartupInfoData::Yes : KStartupInfoData::No);
-    sendChange(id, data);
-}
-#endif
-
-#if KWINDOWSYSTEM_BUILD_DEPRECATED_SINCE(5, 102)
-QByteArray KStartupInfo::startupId()
-{
-    if (s_startup_id.isEmpty()) {
-        KStartupInfoId id = currentStartupIdEnv();
-        resetStartupEnv();
-        s_startup_id = id.id();
-    }
-
-    return s_startup_id;
-}
-#endif
-
 void KStartupInfo::setStartupId(const QByteArray &startup_id)
 {
     if (startup_id == s_startup_id) {
@@ -748,7 +538,6 @@ void KStartupInfo::setStartupId(const QByteArray &startup_id)
         s_startup_id = "0";
     } else {
         s_startup_id = startup_id;
-#if KWINDOWSYSTEM_HAVE_X11
         if (QX11Info::isPlatformX11()) {
             KStartupInfoId id;
             id.initId(startup_id);
@@ -762,31 +551,19 @@ void KStartupInfo::setStartupId(const QByteArray &startup_id)
                 }
             }
         }
-#endif
     }
 }
 
-#if KWINDOWSYSTEM_BUILD_DEPRECATED_SINCE(5, 62)
-void KStartupInfo::setNewStartupId(QWidget *window, const QByteArray &startup_id)
-{
-    // Set the WA_NativeWindow attribute to force the creation of the QWindow.
-    // Without this QWidget::windowHandle() returns 0.
-    window->setAttribute(Qt::WA_NativeWindow, true);
-    setNewStartupId(window->window()->windowHandle(), startup_id);
-}
-#endif
-
 void KStartupInfo::setNewStartupId(QWindow *window, const QByteArray &startup_id)
 {
     Q_ASSERT(window);
     setStartupId(startup_id);
-#if KWINDOWSYSTEM_HAVE_X11
     bool activate = true;
     if (window != nullptr && QX11Info::isPlatformX11()) {
         if (!startup_id.isEmpty() && startup_id != "0") {
             NETRootInfo i(QX11Info::connection(), NET::Supported);
             if (i.isSupported(NET::WM2StartupId)) {
-                KStartupInfo::setWindowStartupId(window->winId(), startup_id);
+                KStartupInfo::Private::setWindowStartupId(window->winId(), startup_id);
                 activate = false; // WM will take care of it
             }
         }
@@ -799,9 +576,6 @@ void KStartupInfo::setNewStartupId(QWindow *window, const QByteArray &startup_id
             KX11Extras::forceActiveWindow(window->winId());
         }
     }
-#else
-    Q_UNUSED(window)
-#endif
 }
 
 KStartupInfo::startup_t KStartupInfo::checkStartup(WId w_P, KStartupInfoId &id_O, KStartupInfoData &data_O)
@@ -845,7 +619,6 @@ KStartupInfo::startup_t KStartupInfo::Private::check_startup_internal(WId w_P, K
         }
         return find_id(id, id_O, data_O) ? Match : NoMatch;
     }
-#if KWINDOWSYSTEM_HAVE_X11
     if (!QX11Info::isPlatformX11()) {
         qCDebug(LOG_KWINDOWSYSTEM) << "check_startup:cantdetect";
         return CantDetect;
@@ -879,7 +652,6 @@ KStartupInfo::startup_t KStartupInfo::Private::check_startup_internal(WId w_P, K
     if (transient_for != QX11Info::appRootWindow() && transient_for != XCB_WINDOW_NONE) {
         return NoMatch;
     }
-#endif
     qCDebug(LOG_KWINDOWSYSTEM) << "check_startup:cantdetect";
     return CantDetect;
 }
@@ -949,7 +721,6 @@ bool KStartupInfo::Private::find_wclass(const QByteArray &_res_name, const QByte
 
 QByteArray KStartupInfo::windowStartupId(WId w_P)
 {
-#if KWINDOWSYSTEM_HAVE_X11
     if (!QX11Info::isPlatformX11()) {
         return QByteArray();
     }
@@ -961,15 +732,10 @@ QByteArray KStartupInfo::windowStartupId(WId w_P)
         ret = groupLeaderInfo.startupId();
     }
     return ret;
-#else
-    Q_UNUSED(w_P)
-    return QByteArray();
-#endif
 }
 
-void KStartupInfo::setWindowStartupId(WId w_P, const QByteArray &id_P)
+void KStartupInfo::Private::setWindowStartupId(WId w_P, const QByteArray &id_P)
 {
-#if KWINDOWSYSTEM_HAVE_X11
     if (!QX11Info::isPlatformX11()) {
         return;
     }
@@ -978,10 +744,6 @@ void KStartupInfo::setWindowStartupId(WId w_P, const QByteArray &id_P)
     }
     NETWinInfo info(QX11Info::connection(), w_P, QX11Info::appRootWindow(), NET::Properties(), NET::Properties2());
     info.setStartupId(id_P.constData());
-#else
-    Q_UNUSED(w_P)
-    Q_UNUSED(id_P)
-#endif
 }
 
 void KStartupInfo::setTimeout(unsigned int secs_P)
@@ -1051,11 +813,9 @@ void KStartupInfo::Private::clean_all_noncompliant()
 QByteArray KStartupInfo::createNewStartupId()
 {
     quint32 timestamp = 0;
-#if KWINDOWSYSTEM_HAVE_X11
     if (QX11Info::isPlatformX11()) {
         timestamp = QX11Info::getTimestamp();
     }
-#endif
     return KStartupInfo::createNewStartupIdForTimestamp(timestamp);
 }
 
@@ -1064,15 +824,7 @@ QByteArray KStartupInfo::createNewStartupIdForTimestamp(quint32 timestamp)
     // Assign a unique id, use hostname+time+pid, that should be 200% unique.
     // Also append the user timestamp (for focus stealing prevention).
     struct timeval tm;
-#ifdef Q_OS_WIN
-    // on windows only msecs accuracy instead of usecs like with gettimeofday
-    // XXX: use Win API to get better accuracy
-    qint64 msecsSinceEpoch = QDateTime::currentMSecsSinceEpoch();
-    tm.tv_sec = msecsSinceEpoch / 1000;
-    tm.tv_usec = (msecsSinceEpoch % 1000) * 1000;
-#else
     gettimeofday(&tm, nullptr);
-#endif
     char hostname[256];
     hostname[0] = '\0';
     if (!gethostname(hostname, 255)) {
@@ -1134,18 +886,6 @@ bool KStartupInfoId::setupStartupEnv() const
     return !qputenv(NET_STARTUP_ENV, id()) == 0;
 }
 
-KStartupInfoId KStartupInfo::currentStartupIdEnv()
-{
-    const QByteArray startup_env = qgetenv(NET_STARTUP_ENV);
-    KStartupInfoId id;
-    if (!startup_env.isEmpty()) {
-        id.d->id = startup_env;
-    } else {
-        id.d->id = "0";
-    }
-    return id;
-}
-
 void KStartupInfo::resetStartupEnv()
 {
     qunsetenv(NET_STARTUP_ENV);
@@ -1255,11 +995,6 @@ QString KStartupInfoData::Private::to_text() const
     if (xinerama != -1) {
         ret += QStringLiteral(" XINERAMA=%1").arg(xinerama);
     }
-#if KWINDOWSYSTEM_BUILD_DEPRECATED_SINCE(5, 69)
-    if (launched_by != 0) {
-        ret += QStringLiteral(" LAUNCHED_BY=%1").arg((qptrdiff)launched_by);
-    }
-#endif
     if (!application_id.isEmpty()) {
         ret += QStringLiteral(" APPLICATION_ID=\"%1\"").arg(application_id);
     }
@@ -1296,10 +1031,6 @@ KStartupInfoData::KStartupInfoData(const QString &txt_P)
             d->screen = get_num(*it);
         } else if ((*it).startsWith(QLatin1String("XINERAMA="))) {
             d->xinerama = get_num(*it);
-#if KWINDOWSYSTEM_BUILD_DEPRECATED_SINCE(5, 69)
-        } else if ((*it).startsWith(QLatin1String("LAUNCHED_BY="))) {
-            d->launched_by = (WId)get_num(*it);
-#endif
         } else if ((*it).startsWith(QLatin1String("APPLICATION_ID="))) {
             d->application_id = get_str(*it);
         }
@@ -1355,11 +1086,6 @@ void KStartupInfoData::update(const KStartupInfoData &data_P)
     if (data_P.xinerama() != -1 && xinerama() != -1) { // don't overwrite
         d->xinerama = data_P.xinerama();
     }
-#if KWINDOWSYSTEM_BUILD_DEPRECATED_SINCE(5, 69)
-    if (data_P.launchedBy() != 0 && launchedBy() != 0) { // don't overwrite
-        d->launched_by = data_P.launchedBy();
-    }
-#endif
     if (!data_P.applicationId().isEmpty() && applicationId().isEmpty()) { // don't overwrite
         d->application_id = data_P.applicationId();
     }
@@ -1538,18 +1264,6 @@ int KStartupInfoData::xinerama() const
     return d->xinerama;
 }
 
-#if KWINDOWSYSTEM_BUILD_DEPRECATED_SINCE(5, 69)
-void KStartupInfoData::setLaunchedBy(WId window)
-{
-    d->launched_by = window;
-}
-
-WId KStartupInfoData::launchedBy() const
-{
-    return d->launched_by;
-}
-#endif
-
 void KStartupInfoData::setApplicationId(const QString &desktop)
 {
     if (desktop.startsWith(QLatin1Char('/'))) {
@@ -1558,9 +1272,6 @@ void KStartupInfoData::setApplicationId(const QString &desktop)
     }
     // the spec requires this is always a full path, in order for everyone to be able to find it
     QString desk = QStandardPaths::locate(QStandardPaths::ApplicationsLocation, desktop);
-    if (desk.isEmpty()) {
-        desk = QStandardPaths::locate(QStandardPaths::GenericDataLocation, QLatin1String("kservices5/") + desktop);
-    }
     if (desk.isEmpty()) {
         return;
     }
