@@ -50,9 +50,7 @@ public:
 };
 
 WindowSystem::WindowSystem()
-    : QObject()
-    , KWindowSystemPrivateV2()
-    , m_lastToken(qEnvironmentVariable("XDG_ACTIVATION_TOKEN"))
+    : m_lastToken(qEnvironmentVariable("XDG_ACTIVATION_TOKEN"))
 {
     m_windowManagement = new WindowManagement;
 }
@@ -76,6 +74,7 @@ void WindowSystem::activateWindow(QWindow *win, long int time)
     activation->activate(m_lastToken, s);
 }
 
+#if KWINDOWSYSTEM_BUILD_DEPRECATED_SINCE(6, 19)
 void WindowSystem::requestToken(QWindow *window, uint32_t serial, const QString &app_id)
 {
     if (window) {
@@ -95,13 +94,11 @@ void WindowSystem::requestToken(QWindow *window, uint32_t serial, const QString
     auto waylandApp = qGuiApp->nativeInterface<QNativeInterface::QWaylandApplication>();
     auto seat = waylandApp ? waylandApp->lastInputSeat() : nullptr;
     auto tokenReq = activation->requestXdgActivationToken(seat, wlSurface, serial, app_id);
-    connect(tokenReq, &WaylandXdgActivationTokenV1::failed, KWindowSystem::self(), [serial, app_id]() {
-        Q_EMIT KWaylandExtras::self()->xdgActivationTokenArrived(serial, {});
-    });
     connect(tokenReq, &WaylandXdgActivationTokenV1::done, KWindowSystem::self(), [serial](const QString &token) {
         Q_EMIT KWaylandExtras::self()->xdgActivationTokenArrived(serial, token);
     });
 }
+#endif
 
 void WindowSystem::setCurrentToken(const QString &token)
 {
@@ -228,40 +225,12 @@ void WindowSystem::setMainWindow(QWindow *window, const QString &handle)
         doSetMainWindow(window, handle);
     } else {
         // We can only import an XDG toplevel.
-        // QWaylandWindow::surfaceRoleCreated is only in Qt 6.8,
-        // in earlier versions wait for the window be exposed,
-        // since QWaylandWindow::wlSurfaceCreated is too early.
-#if QT_VERSION < QT_VERSION_CHECK(6, 8, 0)
-        window->setProperty(c_kdeXdgForeignPendingHandleProperty, handle);
-        window->installEventFilter(this);
-#else
         connect(waylandWindow, &QNativeInterface::Private::QWaylandWindow::surfaceRoleCreated, window, [window, handle] {
             doSetMainWindow(window, handle);
         });
-#endif
     }
 }
 
-bool WindowSystem::eventFilter(QObject *watched, QEvent *event)
-{
-#if QT_VERSION < QT_VERSION_CHECK(6, 8, 0)
-    if (event->type() == QEvent::Expose) {
-        auto *window = static_cast<QWindow *>(watched);
-        if (window->isExposed()) {
-            const QString handle = window->property(c_kdeXdgForeignPendingHandleProperty).toString();
-            if (!handle.isEmpty()) {
-                doSetMainWindow(window, handle);
-                window->setProperty(c_kdeXdgForeignPendingHandleProperty, QVariant());
-            }
-
-            window->removeEventFilter(this);
-        }
-    }
-#endif
-
-    return QObject::eventFilter(watched, event);
-}
-
 void WindowSystem::doSetMainWindow(QWindow *window, const QString &handle)
 {
     Q_ASSERT(window);
@@ -306,4 +275,25 @@ void WindowSystem::doSetMainWindow(QWindow *window, const QString &handle)
     }
 }
 
+QFuture<QString> WindowSystem::xdgActivationToken(QWindow *window, uint32_t serial, const QString &appId)
+{
+    WaylandXdgActivationV1 *activation = WaylandXdgActivationV1::self();
+    if (!activation->isActive()) {
+        return QtFuture::makeReadyValueFuture(QString());
+    }
+
+    auto waylandApp = qGuiApp->nativeInterface<QNativeInterface::QWaylandApplication>();
+    if (!waylandApp) {
+        return QtFuture::makeReadyValueFuture(QString());
+    }
+
+    if (window) {
+        window->create();
+    }
+    wl_surface *wlSurface = surfaceForWindow(window);
+
+    auto token = activation->requestXdgActivationToken(waylandApp->lastInputSeat(), wlSurface, serial, appId);
+    return token->future();
+}
+
 #include "moc_windowsystem.cpp"
